#!/bin/bash

PARM=${1}
UDEVADM=/sbin/udevadm
SCRIPTDIR=`dirname ${0}`

PRINTER_VID="043d:"
IS_OEM_DELL=`echo ${SCRIPTDIR} | grep 'dell'`
if [ $? -eq 0 ]; then
    PRINTER_VID="413c:"
fi

genericGetList() {
    if [ -f ${UDEVADM} ]; then
        busid=`lsusb | grep ${PRINTER_VID} | awk '{print $2 ":" $4}'`
        for item in $busid
        do
            bus=`echo $item | awk -F: '{print $1}'`
            dev=`echo $item | awk -F: '{print $2}'`
            lnk=`${UDEVADM} info -q path -n /dev/bus/usb/$bus/$dev`
            pro=`${UDEVADM} info -a -p $lnk | grep 'ATTR{product}==' | sed 's/ATTR{product}==//g' | awk -F\" '{print $2}'`
            mfg=`${UDEVADM} info -a -p $lnk | grep 'ATTR{manufacturer}==' | sed 's/ATTR{manufacturer}==//g' | awk -F\" '{print $2}'`
            ser=`${UDEVADM} info -a -p $lnk | grep 'ATTR{serial}==' | sed 's/ATTR{serial}==//g' | awk -F\" '{print $2}'`
            escpro=`echo $pro | sed 's/ /%20/g'`
            echo "$bus:$dev;$mfg $pro;usb://$mfg/$escpro?serial=$ser"
        done
    fi
}

wsuGetList() {
    libusb_helper="${SCRIPTDIR}/../usbdevid"
    if [ -f ${UDEVADM} ]; then
        busid=`lsusb | grep ${PRINTER_VID} | awk '{print $2 ":" $4}'`
        for item in $busid
        do
            bus=`echo $item | awk -F: '{print $1}'`
            dev=`echo $item | awk -F: '{print $2}'`
            nfo=`${libusb_helper} -b ${bus} -d ${dev}`
            model=`echo $nfo | sed 's/^.*MODEL://g' | sed 's/;.*$//g'`

            isMAN=`expr match "$nfo" MANUFACTURER`
            if [ "$isMAN" -gt 0 ]; then
                mfg=`echo $nfo | sed 's/^.*MANUFACTURER://g' | sed 's/;.*$//g'`
		    else		
                mfg=`echo $nfo | sed 's/^.*MFG://g' | sed 's/;.*$//g'`
            fi

            instr=`expr match "$model" "$mfg"`
            if [ "$instr" -gt 0 ]; then
                # removing 'manufacturer' from model
                model=`echo "$model" | sed "s/$mfg \(.*\)/\1/"`
            fi

            escmodel=`echo $model | sed 's/ /%20/g'`
            if [[ $nfo =~ SN: ]]; then
                serial=`echo $nfo | sed 's/^.*SN://g' | sed 's/;.*$//g'`
                echo "$bus:$dev;$mfg $model;usb://$mfg/$escmodel?serial=$serial"
            else		
                echo "$bus:$dev;$mfg $model;usb://$mfg/$escmodel"
            fi
        done
    fi
}

case $PARM in
    wsu) wsuGetList
         ;;
    *) genericGetList
         ;;
esac     
