#!/bin/sh


PARM=$1
PARM2=$2
OEM=
SCRIPTDIR=

SCRIPTDIR=`dirname ${0}`		

listDevices() {
    cmd=${1}
    type=${2}
    lst=""
    if [ "${OEM}" = "IPS" ]; then
         # XXX: Special case for Printer(OEM), since it's possible that the
         #      printer would return "InfoPrint" instead of "IPS".
         #      And we're always the last ones to know about these changes ;)
         lst=`${cmd} | sed 's/\ /\//g' | grep ${OEM}`
         if [ "$lst" = "" ]; then
             lst=`${cmd} | sed 's/\ /\//g' | grep "InfoPrint"`
         fi
    else
         lst=`${cmd} | sed 's/\ /\//g' | grep ${OEM}`
    fi

    for i in $lst 
    do
	    num=`echo $i | awk -F\; '{print $1}'`
        model=`echo $i | awk -F\; '{print $2}' | sed 's/\// /g' | sed 's/MANUFACTURER:Lexmark International //g'`
        if [ "${type}" = "usblp" ]; then
            echo "${model}&&:&&/dev/usb/lp${num}"
        else
            echo "${model}&&:&&${num}"
        fi
    done
}

countDevices() {
    cmd=${1}
    if [ "${OEM}" = "IPS" ]; then
         # XXX: Special case for Printer(OEM), since it's possible that the
         #      printer would return "InfoPrint" instead of "IPS".
         #      And we're always the last ones to know about these changes ;)
         num=`${cmd} | grep ${OEM} | wc -l`
         if [ "$num" = "0" ]; then
             num=`${cmd} | grep "InfoPrint" | wc -l`
         fi
         echo $num
    else
         num=`${cmd} | grep ${OEM} | wc -l`
         echo $num
    fi 
}

listDevices_libusb(){
    if [ -f ${SCRIPTDIR}/findby_libusb.sh ]; then
        if [ "${RAWMODE}" = "1" ]; then
            ${SCRIPTDIR}/findby_libusb.sh wsu            
        else            
            listDevices "${SCRIPTDIR}/findby_libusb.sh wsu" "libusb"
        fi            
    fi        
}

listDevices_usblp(){
    if [ -f ${SCRIPTDIR}/findby_usblp.sh ]; then
        if [ "${RAWMODE}" = "1" ]; then
            ${SCRIPTDIR}/findby_usblp.sh wsu
        else            
            listDevices "${SCRIPTDIR}/findby_usblp.sh wsu" "usblp"        
        fi            
    fi        
}

# TODO: need to optimize counting. there is no need to parse model name,
#       manufacturer, etc... indside findby_libusb.sh, count should only
#       count and do nothing else
countDevices_libusb() {
    if [ -f ${SCRIPTDIR}/findby_libusb.sh ]; then
        countDevices "${SCRIPTDIR}/findby_libusb.sh wsu"        
    fi        
}

# TODO: need to optimize counting. there is no need to parse model name,
#       manufacturer, etc... indside findby_libusb.sh, count should only
#       count and do nothing else
countDevices_usblp(){
    if [ -f ${SCRIPTDIR}/findby_usblp.sh ]; then
        countDevices "${SCRIPTDIR}/findby_usblp.sh wsu"        
    fi
}

lp_exists() {
    lps_dir="/dev/usb"

    if [ -d ${lps_dir} ]; then
         _ret=`find ${lps_dir} -name "lp*" | wc -l`
         echo "$_ret"
    else
         echo "0"
    fi
}    

case $PARM2 in
    Printer) OEM="IPS";
             ;;
    Dell)    OEM="Dell";
             ;;
    *)       OEM="Lexmark";
             ;;
esac

exists=`lp_exists`
if [ "${exists}" = "0" ]; then
    countDevices_func="countDevices_libusb"    
    listDevices_func="listDevices_libusb"    
else    
    countDevices_func="countDevices_usblp"    
    listDevices_func="listDevices_usblp"    
fi    

RAWMODE=0
case $PARM in
    -c) ${countDevices_func}
        ;;
    -q) ${listDevices_func}
        ;;
    *)  RAWMODE=1; ${listDevices_func}
        ;;
esac
